@@ -7,10 +7,12 @@ from .exceptions import (
     VerifyError,
 )
 from .key import Key
+from .key_interface import KeyInterface
 from .paseto import Paseto
 from .pyseto import decode, encode
+from .token import Token
 
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __title__ = "PySETO"
 __description__ = "A Python implementation of PASETO"
 __url__ = "https://pyseto.readthedocs.io"
@@ -24,8 +26,10 @@ __all__ = [
     "encode",
     "decode",
     "Key",
+    "KeyInterface",
     "Paseto",
     "PysetoError",
+    "Token",
     "DecryptError",
     "EncryptError",
     "NotSupportedError",
