@@ -23,13 +23,13 @@ class TestV4Local:
     )
     def test_v4_local_new_with_invalid_arg(self, key, msg):
         with pytest.raises(ValueError) as err:
-            Key.new("v4", "local", key)
+            Key.new(4, "local", key)
             pytest.fail("Key.new() should fail.")
         assert msg in str(err.value)
 
     def test_v4_local_decrypt_via_decode_with_wrong_key(self):
-        k1 = Key.new("v4", "local", b"our-secret")
-        k2 = Key.new("v4", "local", b"others-secret")
+        k1 = Key.new(4, "local", b"our-secret")
+        k2 = Key.new(4, "local", b"others-secret")
         token = pyseto.encode(k1, b"Hello world!")
         with pytest.raises(DecryptError) as err:
             pyseto.decode(k2, token)
@@ -37,7 +37,7 @@ class TestV4Local:
         assert "Failed to decrypt." in str(err.value)
 
     def test_v4_local_encrypt_with_invalid_arg(self):
-        k = Key.new("v4", "local", b"our-secret")
+        k = Key.new(4, "local", b"our-secret")
         with pytest.raises(EncryptError) as err:
             k.encrypt(None)
             pytest.fail("pyseto.encrypt() should fail.")
@@ -54,7 +54,7 @@ class TestV4Local:
         ],
     )
     def test_v4_local_encrypt_via_encode_with_wrong_nonce(self, nonce):
-        k = Key.new("v4", "local", b"our-secret")
+        k = Key.new(4, "local", b"our-secret")
         with pytest.raises(ValueError) as err:
             pyseto.encode(k, b"Hello world!", nonce=nonce)
             pytest.fail("pyseto.encode() should fail.")
@@ -63,10 +63,12 @@ class TestV4Local:
     @pytest.mark.parametrize(
         "paserk, msg",
         [
-            ("xx.local.AAAAAAAAAAAAAAAA", "Invalid PASERK version for a v4.local key."),
-            ("k1.local.AAAAAAAAAAAAAAAA", "Invalid PASERK version for a v4.local key."),
-            ("k4.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK type for a v4.local key."),
-            ("k4.public.AAAAAAAAAAAAAAAA", "Invalid PASERK type for a v4.local key."),
+            ("xx.local.AAAAAAAAAAAAAAAA", "Invalid PASERK version: xx."),
+            ("k1.local.AAAAAAAAAAAAAAAA", "Invalid PASERK version: k1."),
+            ("k4.local.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK format."),
+            ("k4.public.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK format."),
+            ("k4.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK type: xxx."),
+            ("k4.public.AAAAAAAAAAAAAAAA", "Invalid PASERK type: public."),
         ],
     )
     def test_v4_local_from_paserk_with_invalid_args(self, paserk, msg):
@@ -83,8 +85,8 @@ class TestV4Public:
     """
 
     def test_v4_public_verify_via_encode_with_wrong_key(self):
-        sk = Key.new("v4", "public", load_key("keys/private_key_ed25519.pem"))
-        pk = Key.new("v4", "public", load_key("keys/public_key_ed25519_2.pem"))
+        sk = Key.new(4, "public", load_key("keys/private_key_ed25519.pem"))
+        pk = Key.new(4, "public", load_key("keys/public_key_ed25519_2.pem"))
         token = pyseto.encode(sk, b"Hello world!")
         with pytest.raises(VerifyError) as err:
             pyseto.decode(pk, token)
@@ -94,16 +96,12 @@ class TestV4Public:
     @pytest.mark.parametrize(
         "paserk, msg",
         [
-            (
-                "xx.public.AAAAAAAAAAAAAAAA",
-                "Invalid PASERK version for a v4.public key.",
-            ),
-            (
-                "k1.public.AAAAAAAAAAAAAAAA",
-                "Invalid PASERK version for a v4.public key.",
-            ),
-            ("k4.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK type for a v4.public key."),
-            ("k4.local.AAAAAAAAAAAAAAAA", "Invalid PASERK type for a v4.public key."),
+            ("xx.public.AAAAAAAAAAAAAAAA", "Invalid PASERK version: xx."),
+            ("k1.public.AAAAAAAAAAAAAAAA", "Invalid PASERK version: k1."),
+            ("k4.public.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK format."),
+            ("k4.local.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK format."),
+            ("k4.xxx.AAAAAAAAAAAAAAAA", "Invalid PASERK type: xxx."),
+            ("k4.local.AAAAAAAAAAAAAAAA", "Invalid PASERK type: local."),
         ],
     )
     def test_v4_public_from_paserk_with_invalid_args(self, paserk, msg):
